Index: trunk/utils/mogtool
===================================================================
--- trunk/utils/mogtool (revision 1130)
+++ trunk/utils/mogtool (revision 1198)
@@ -281,5 +281,5 @@
 =item 0
 
-Sucess during operation.
+Success during operation.
 
 =item 1
@@ -289,5 +289,5 @@
 =item 2
 
-Some fatal error occured.
+Some fatal error occurred.
 
 =back
@@ -1170,5 +1170,5 @@
     }
 
-    # several cases.. going to stdout?
+    # several cases.. going to STDOUT?
     if ($dest eq '-') {
         *O = *STDOUT;
@@ -1183,5 +1183,5 @@
             }
             if (-b $dest) {
-                # if we're targetting a block device...
+                # if we're targeting a block device...
                 warn "FIXME: add in block checking\n";
                 open O, ">$dest"
@@ -1239,5 +1239,5 @@
     # now make sure we have enough data
 #$ mogtool [opts] extract <key> {<file>,<dir>,<device>}
-                                 #=>  -  (for stdout)    (if compressed, add "z" flag)
+                                 #=>  -  (for STDOUT)    (if compressed, add "z" flag)
                                  #=>  .   (to untar)     (if compressed, do nothing???, make .tar.gz file -- unless they use -z again?)
                                  #=> /dev/sda4  (but check /proc/partitions that it's big enough)  (if compress, Compress::Zlib to ungzip
@@ -1258,5 +1258,5 @@
     $dkey = "_big_info:$key" if $opts{big};
     
-    # list all pathes for the file
+    # list all paths for the file
     my $ct = 0;
     my @paths = [];
@@ -1303,5 +1303,5 @@
     abortWithUsage("key pattern required") unless $key_pattern;
 
-    # list all files matchine a key
+    # list all files matching a key
     my ($ct, $after, $list);
     $ct = 0;
@@ -1417,5 +1417,5 @@
 
 $ mogtool [opts] extract <key> {<file>,<dir>,<device>}
-                                  =>  -  (for stdout)    (if compressed, add "z" flag)
+                                  =>  -  (for STDOUT)    (if compressed, add "z" flag)
                                   =>  .   (to untar)     (if compressed, do nothing???, make .tar.gz file -- unless they use -z again?)
                                   => /dev/sda4  (but check /proc/partitions that it's big enough)  (if compress, Compress::Zlib to ungzip)
Index: trunk/utils/debian/control
===================================================================
--- trunk/utils/debian/control (revision 168)
+++ trunk/utils/debian/control (revision 1198)
@@ -9,5 +9,5 @@
 Architecture: all
 Depends: ${perl:Depends}, libcompress-zlib-perl, libwww-perl, libmogilefs-perl
-Description: utilities to manipulate mogileFS filesystems
+Description: utilities to manipulate MogileFS filesystems
  The mogilefs-utils package contains tools to administrate and work with the 
- mogileFS filesystem from Danga Interactive.
+ MogileFS filesystem from Danga Interactive.
Index: trunk/utils/mogadm
===================================================================
--- trunk/utils/mogadm (revision 1136)
+++ trunk/utils/mogadm (revision 1198)
@@ -113,5 +113,5 @@
             },
             modify => {
-                des => "Modify a device's propereties.",
+                des => "Modify a device's properties.",
                 args => "<hostname> <devid> [opts]",
                 opts => {
@@ -119,5 +119,5 @@
                     "<devid>"    => "Numeric devid to modify.",
                     "--status=s" => "One of {alive,dead,down,drain,readonly}",
-                    "--weight=i" => "Postive numeric weight for device",
+                    "--weight=i" => "Positive numeric weight for device",
                 },
             },
@@ -158,5 +158,5 @@
                     "<domain>" => "Domain to add class to.",
                     "<class>"  => "Name of class to add.",
-                    "--mindevcount=i" => "Mininum number of replicas.",
+                    "--mindevcount=i" => "Minimum number of replicas.",
                 },
             },
@@ -167,5 +167,5 @@
                     "<domain>" => "Domain to add class to.",
                     "<class>"  => "Name of class to add.",
-                    "--mindevcount=i" => "Mininum number of replicas.",
+                    "--mindevcount=i" => "Minimum number of replicas.",
                 },
             },
@@ -1448,5 +1448,5 @@
 Show the status of the presently active (or last if none active) fsck. This
 includes what FIDs are being checked, time statistics, check type as well as a
-summary of problems encounted so far.
+summary of problems encountered so far.
 
 =item B<fsck stop>
Index: trunk/fuse/mount-filepaths
===================================================================
--- trunk/fuse/mount-filepaths (revision 1135)
+++ trunk/fuse/mount-filepaths (revision 1198)
@@ -205,5 +205,5 @@
     --file-perms PERMS
         The default file permissions for all files in the mounted MogileFS
-        filesystem.  Since MogilefS does not store this information currently
+        filesystem.  Since MogileFS does not store this information currently
         it must be faked.
 
Index: trunk/server-plugins/MogileFS-Network/t/hosts-per-zone-replpol.t
===================================================================
--- trunk/server-plugins/MogileFS-Network/t/hosts-per-zone-replpol.t (revision 1179)
+++ trunk/server-plugins/MogileFS-Network/t/hosts-per-zone-replpol.t (revision 1198)
@@ -21,5 +21,5 @@
    "ideal(3,4)", "need host2");
 
-# still needs to be on host2, even though 2 coies on host1
+# still needs to be on host2, even though 2 copies on host1
 is(rr("min=2  h1[d1=X d2=X] h2[d3=_ d4=_]"),
    "ideal(3,4)", "need host2, even though 2 on host1");
@@ -42,5 +42,5 @@
 
 # minimum hosts is 3, only 2 available hosts. This test differs from
-# the one in multiplehosts because elavating these results to be 'ideal'
+# the one in multiplehosts because elevating these results to be 'ideal'
 # adds complexity that is unnecessary in my eyes.
 is(rr("min=3 h1[d1=_ d2=X] h2[d3=X d4=_]"),
Index: trunk/server-plugins/MogileFS-Network/lib/MogileFS/Network.pm
===================================================================
--- trunk/server-plugins/MogileFS-Network/lib/MogileFS/Network.pm (revision 1179)
+++ trunk/server-plugins/MogileFS-Network/lib/MogileFS/Network.pm (revision 1198)
@@ -76,5 +76,5 @@
 }
 
-# This is a seperate subroutine so I can redefine it at test time.
+# This is a separate subroutine so I can redefine it at test time.
 sub get_setting {
     my $key = shift;
Index: trunk/server-plugins/MogileFS-Network/lib/MogileFS/ReplicationPolicy/MultipleNetworks.pm
===================================================================
--- trunk/server-plugins/MogileFS-Network/lib/MogileFS/ReplicationPolicy/MultipleNetworks.pm (revision 1162)
+++ trunk/server-plugins/MogileFS-Network/lib/MogileFS/ReplicationPolicy/MultipleNetworks.pm (revision 1198)
@@ -124,5 +124,5 @@
 
     my @ideal         = grep { ! $skip_host{$_->hostid} } @all_dests;
-    # wrong network is less desparate than wrong host
+    # wrong network is less desperate than wrong host
     my @network_desp  = grep {   $skip_host{$_->hostid} &&
                                  $skip_host{$_->hostid} eq AVOIDNETWORK } @all_dests;
@@ -161,5 +161,5 @@
 {
     my %cache; # '192.168.0.0/24' => Net::Netmask->new2('192.168.0.0/24');
-    my $age;   # increments everytime we look
+    my $age;   # increments every time we look
 
     # turn a server ip into a network
Index: trunk/server-plugins/MogileFS-Plugin-FilePaths/lib/MogileFS/Plugin/FilePaths.pm
===================================================================
--- trunk/server-plugins/MogileFS-Plugin-FilePaths/lib/MogileFS/Plugin/FilePaths.pm (revision 1103)
+++ trunk/server-plugins/MogileFS-Plugin-FilePaths/lib/MogileFS/Plugin/FilePaths.pm (revision 1198)
@@ -21,5 +21,5 @@
 # MogileFS to consider the plugin to have loaded successfully.  if you return a
 # non-true value, you MUST NOT install any handlers or other changes to the system.
-# if you install something here, you MUST uninstall it in the unload sub.
+# if you install something here, you MUST un-install it in the unload sub.
 
 sub _parse_path {
@@ -279,5 +279,5 @@
 
 # this sub is called at the end or when the module is being unloaded, this needs to
-# unregister any registered methods, etc.  you MUST uninstall everything that the
+# unregister any registered methods, etc.  you MUST un-install everything that the
 # plugin has previously installed.
 sub unload {
Index: trunk/server-plugins/MogileFS-Plugin-FilePaths/Makefile.PL
===================================================================
--- trunk/server-plugins/MogileFS-Plugin-FilePaths/Makefile.PL (revision 810)
+++ trunk/server-plugins/MogileFS-Plugin-FilePaths/Makefile.PL (revision 1198)
@@ -7,5 +7,5 @@
     VERSION_FROM            => 'lib/MogileFS/Plugin/FilePaths.pm',
     AUTHOR                  => 'Jonathan Steinert <hachi@cpan.org>',
-    ABSTRACT                => 'Plugin for mogilefs server represending a UNIX like filesystem on top of mogilefs.',
+    ABSTRACT                => 'Plugin for mogilefs server representing a UNIX like filesystem on top of mogilefs.',
     PREREQ_PM               => {
         'MogileFS::Plugin::MetaData'    => '0.01',
Index: trunk/server-plugins/MogileFS-Plugin-FilePaths/MogileFS-Plugin-FilePaths.spec
===================================================================
--- trunk/server-plugins/MogileFS-Plugin-FilePaths/MogileFS-Plugin-FilePaths.spec (revision 1103)
+++ trunk/server-plugins/MogileFS-Plugin-FilePaths/MogileFS-Plugin-FilePaths.spec (revision 1198)
@@ -1,4 +1,4 @@
 name:      perl-MogileFS-Plugin-FilePaths
-summary:   perl-MogileFS-Plugin-FilePaths - MogileFS Tracker plugin to reprepsent a traditional unix filesystem in mogilefs.
+summary:   perl-MogileFS-Plugin-FilePaths - MogileFS Tracker plugin to represent a traditional unix filesystem in mogilefs.
 version:   0.02
 release:   1
@@ -13,5 +13,5 @@
 
 %description
-MogileFS Tracker plugin to reprepsent a traditional unix filesystem in mogilefs.
+MogileFS Tracker plugin to represent a traditional unix filesystem in mogilefs.
 
 %prep
Index: trunk/server/debian/control
===================================================================
--- trunk/server/debian/control (revision 1186)
+++ trunk/server/debian/control (revision 1198)
@@ -20,5 +20,5 @@
 Description: scalable distributed filesystem from Danga Interactive
  MogileFS is an open-source, application-level distributed filesystem. It
- creates a host-nuetral, filesystem-agnostic method of distributing files
+ creates a host-neutral, filesystem-agnostic method of distributing files
  that has many advantages over NFS and single-machine raid.  This set
  of utilities is very scalable and can handle Livejournal.com's load, for
Index: trunk/server/debian/changelog
===================================================================
--- trunk/server/debian/changelog (revision 236)
+++ trunk/server/debian/changelog (revision 1198)
@@ -1,5 +1,5 @@
 mogilefs-server (1.00-2) unstable; urgency=low
 
-  * fix dataloss bug when the 'tempfile' table is Innodb and the
+  * fix data loss bug when the 'tempfile' table is InnoDB and the
     server is restarted while the tempfile table is empty.
 
Index: trunk/server/mogautomount
===================================================================
--- trunk/server/mogautomount (revision 1137)
+++ trunk/server/mogautomount (revision 1198)
@@ -113,5 +113,5 @@
 0 on success or inaction because no action needed to happen.
 
-1 on partial failure (some mounts succeeed).
+1 on partial failure (some mounts succeed).
 
 2 on total failure (things had to be done, but nothing was).
Index: trunk/server/MogileFS-Server.spec
===================================================================
--- trunk/server/MogileFS-Server.spec (revision 1182)
+++ trunk/server/MogileFS-Server.spec (revision 1198)
@@ -1,4 +1,4 @@
 name:      MogileFS-Server
-summary:   MoilgeFS-Server - MogileFS Server daemons and utilities.
+summary:   MogileFS-Server - MogileFS Server daemons and utilities.
 version:   2.17
 release:   1
Index: trunk/server/t/20-filepaths.t
===================================================================
--- trunk/server/t/20-filepaths.t (revision 1169)
+++ trunk/server/t/20-filepaths.t (revision 1198)
@@ -24,5 +24,5 @@
 # etc
 
-plan skip_all => "Filepaths plugin has been seperated from the server, a bit of work is needed to make the tests run again.";
+plan skip_all => "Filepaths plugin has been separated from the server, a bit of work is needed to make the tests run again.";
 exit 0;
 
Index: trunk/server/t/10-weighting.t
===================================================================
--- trunk/server/t/10-weighting.t (revision 1169)
+++ trunk/server/t/10-weighting.t (revision 1198)
@@ -12,5 +12,5 @@
     $ENV{TESTING} = 1;
     $ENV{T_FAKE_IO_DEV1} = 95; # Simulating high device load (should get fewer requests).
-    $ENV{T_FAKE_IO_DEV2} = 5;  # Simulating low device load (shoudld get more requests).
+    $ENV{T_FAKE_IO_DEV2} = 5;  # Simulating low device load (should get more requests).
 }
 
Index: trunk/server/t/multiple-hosts-replpol.t
===================================================================
--- trunk/server/t/multiple-hosts-replpol.t (revision 1169)
+++ trunk/server/t/multiple-hosts-replpol.t (revision 1198)
@@ -21,5 +21,5 @@
    "ideal(3,4)", "need host2");
 
-# still needs to be on host2, even though 2 coies on host1
+# still needs to be on host2, even though 2 copies on host1
 is(rr("min=2  h1[d1=X d2=X] h2[d3=_ d4=_]"),
    "ideal(3,4)", "need host2, even though 2 on host1");
Index: trunk/server/t/mogstored-shutdown.t
===================================================================
--- trunk/server/t/mogstored-shutdown.t (revision 1169)
+++ trunk/server/t/mogstored-shutdown.t (revision 1198)
@@ -66,5 +66,5 @@
 sub exist_pid {
     unless (`netstat -nap --inet` =~ m!127\.0\.1\.1:750[10].+LISTEN\s+(\d+)/!) {
-        die "Could't find pid of daemonized process.\n";
+        die "Couldn't find pid of daemonized process.\n";
     }
     return $1;
Index: trunk/server/mogstored
===================================================================
--- trunk/server/mogstored (revision 1115)
+++ trunk/server/mogstored (revision 1198)
@@ -169,5 +169,5 @@
 
     # parse the mogstored config file, which is just lines of comments and
-    # "key = value" lines, where keys are just the same as commandline
+    # "key = value" lines, where keys are just the same as command line
     # options.
     die "Config file $opt_config doesn't exist.\n" unless -e $conffile;
@@ -214,5 +214,5 @@
     });
 
-    # old Gearman::Servers didn't return pid integegers
+    # old Gearman::Servers didn't return pid integers
     if ($pid =~ /^\d+$/) {
         Mogstored->on_pid_death($pid, \&start_fidsizes_worker);
Index: trunk/server/TODO
===================================================================
--- trunk/server/TODO (revision 1054)
+++ trunk/server/TODO (revision 1198)
@@ -1,6 +1,6 @@
--- if run out filedescriptors in mogilefsd, mogilefsd shouldn't crash.  it might
+-- if run out file descriptors in mogilefsd, mogilefsd shouldn't crash.  it might
    now.  needs a test.
 
--- change debug level at runtime from mgmt port, propogate to children.
+-- change debug level at runtime from mgmt port, propagate to children.
 
 -- MogileFS::Device ->make_directory on lighttpd isn't exactly right, as WebDAV
Index: trunk/server/doc/fsck-notes.txt
===================================================================
--- trunk/server/doc/fsck-notes.txt (revision 384)
+++ trunk/server/doc/fsck-notes.txt (revision 1198)
@@ -29,5 +29,5 @@
 # todo: stat command to get count of rows in needs_replicate  (!repl replacement)
 
-# provide command to drop fsck table to force global reindexing
+# provide command to drop fsck table to force global re-indexing
 # interface from fsck job to replicate job.  or do it ourselves sharing code.  (probably sharing code)
 # perhaps command-line version is just running:
Index: trunk/server/doc/memcache-support.txt
===================================================================
--- trunk/server/doc/memcache-support.txt (revision 718)
+++ trunk/server/doc/memcache-support.txt (revision 1198)
@@ -6,5 +6,5 @@
 still maintain it's (usually) stupid.
 
-Reall, you should cache get_paths requests in your application,
+Really, you should cache get_paths requests in your application,
 avoiding an extra round-trip to the trackers that could be avoided on
 a cache hit.
@@ -28,5 +28,5 @@
     set_server_setting key=memcache_servers&value=127.0.0.1:11211
 
-(where value is a comman-separated list, if you have multiple)
+(where value is a comma-separated list, if you have multiple)
 
 And then all future get_paths requests with noverify=1 (which now
Index: trunk/server/doc/testing.txt
===================================================================
--- trunk/server/doc/testing.txt (revision 1064)
+++ trunk/server/doc/testing.txt (revision 1198)
@@ -26,5 +26,5 @@
 Manual tests
 ============
-If you only want to run some part of the testsuite, or you want detailed
+If you only want to run some part of the test suite, or you want detailed
 output as to why a test failed, you can run as follows:
 $ MOGTEST_DBTYPE=<dbtype> perl -Ilib t/<foobar>.t
Index: trunk/server/lib/Mogstored/SideChannelClient.pm
===================================================================
--- trunk/server/lib/Mogstored/SideChannelClient.pm (revision 975)
+++ trunk/server/lib/Mogstored/SideChannelClient.pm (revision 1198)
@@ -94,5 +94,5 @@
 }
 
-# stop watching writability if we've nothing else to
+# stop watching writeability if we've nothing else to
 # write to them.  else just kick off more writes.
 sub event_write {
Index: trunk/server/lib/MogileFS/Config.pm
===================================================================
--- trunk/server/lib/MogileFS/Config.pm (revision 1180)
+++ trunk/server/lib/MogileFS/Config.pm (revision 1198)
@@ -24,5 +24,5 @@
     my ($k, $v) = @_;
 
-    # if a child, propogate to parent
+    # if a child, propagate to parent
     if (my $worker = MogileFS::ProcManager->is_child) {
         $worker->send_to_parent(":set_config_from_child $k $v");
@@ -132,5 +132,5 @@
 
     # Fill in defaults for those values which were either loaded from config or
-    # specified on the command line. Command line takes precendence, then values in
+    # specified on the command line. Command line takes precedence, then values in
     # the config file, then the defaults.
     $daemonize      = choose_value( 'daemonize', 0 );
Index: trunk/server/lib/MogileFS/Domain.pm
===================================================================
--- trunk/server/lib/MogileFS/Domain.pm (revision 1159)
+++ trunk/server/lib/MogileFS/Domain.pm (revision 1198)
@@ -75,5 +75,5 @@
 # flushes locally (for things like "get_domains" or "get_hosts", where
 # it needs to be locally correct for the semantics of the command, but
-# no need to propogate a cache invalidation to our peers)
+# no need to propagate a cache invalidation to our peers)
 sub invalidate_cache {
     $last_load = 0;
Index: trunk/server/lib/MogileFS/Worker.pm
===================================================================
--- trunk/server/lib/MogileFS/Worker.pm (revision 1036)
+++ trunk/server/lib/MogileFS/Worker.pm (revision 1198)
@@ -222,5 +222,5 @@
 
 # tries to parse generic (not job-specific) commands sent from parent
-# to child.  returns 1 on success, or 0 if comman given isn't generic,
+# to child.  returns 1 on success, or 0 if command given isn't generic,
 # and child should parse.
 # lineref doesn't have \r\n at end.
Index: trunk/server/lib/MogileFS/Util.pm
===================================================================
--- trunk/server/lib/MogileFS/Util.pm (revision 1036)
+++ trunk/server/lib/MogileFS/Util.pm (revision 1198)
@@ -123,5 +123,5 @@
         unless $sess_id = POSIX::setsid();
 
-    ## Prevent possibility of acquiring a controling terminal
+    ## Prevent possibility of acquiring a controlling terminal
     $SIG{'HUP'} = 'IGNORE';
     if ($pid = fork) { exit 0; }
@@ -140,5 +140,5 @@
     close(STDERR);
 
-    ## Reopen stderr, stdout, stdin to /dev/null
+    ## Reopen STDERR, STDOUT, STDIN to /dev/null
     if ( $MogileFS::DEBUG ) {
         open(STDIN,  "+>/tmp/mogilefsd.log");
Index: trunk/server/lib/MogileFS/ReplicationPolicy/MultipleHosts.pm
===================================================================
--- trunk/server/lib/MogileFS/ReplicationPolicy/MultipleHosts.pm (revision 1142)
+++ trunk/server/lib/MogileFS/ReplicationPolicy/MultipleHosts.pm (revision 1198)
@@ -33,5 +33,5 @@
     # this is the per-class mindevcount (the old way), which is passed in automatically
     # from the replication worker.  but if we have our own configured mindevcount
-    # in class.replpolicy, like "MultipleHosts(3)", then we use the explciit one. otherwise,
+    # in class.replpolicy, like "MultipleHosts(3)", then we use the explicit one. otherwise,
     # if blank, or zero, like "MultipleHosts()", then we use the builtin on
     my $min      = delete $args{min};
Index: trunk/server/lib/MogileFS/HTTPFile.pm
===================================================================
--- trunk/server/lib/MogileFS/HTTPFile.pm (revision 1147)
+++ trunk/server/lib/MogileFS/HTTPFile.pm (revision 1198)
@@ -125,5 +125,5 @@
     my ($host, $port, $uri, $path) = map { $self->{$_} } qw(host port uri url);
 
-    # don't sigpipe us
+    # don't SIGPIPE us
     my $flag_nosignal = MogileFS::Sys->flag_nosignal;
     local $SIG{'PIPE'} = "IGNORE" unless $flag_nosignal;
Index: trunk/server/lib/MogileFS/IOStatWatcher.pm
===================================================================
--- trunk/server/lib/MogileFS/IOStatWatcher.pm (revision 716)
+++ trunk/server/lib/MogileFS/IOStatWatcher.pm (revision 1198)
@@ -27,5 +27,5 @@
 pass it hostnames instead of ip addresses.
 
-Upon successfull connection, the on_stats callback will be called each time the statistics are
+Upon successful connection, the on_stats callback will be called each time the statistics are
 collected. Error states (failed connections, etc.) will trigger retries on 60 second intervals, and
 disconnects will trigger an immediate reconnect.
Index: trunk/server/lib/MogileFS/ReplicationRequest.pm
===================================================================
--- trunk/server/lib/MogileFS/ReplicationRequest.pm (revision 1145)
+++ trunk/server/lib/MogileFS/ReplicationRequest.pm (revision 1198)
@@ -60,5 +60,5 @@
 
 # returns array of MogileFS::Device objs, in preferred order, one of
-# which (but not multiple) would satisify the replication policy
+# which (but not multiple) would satisfy the replication policy
 # for its next step.  at which point the replication policy needs
 # to be asked again what the next step is.
Index: trunk/server/lib/MogileFS/Store.pm
===================================================================
--- trunk/server/lib/MogileFS/Store.pm (revision 1185)
+++ trunk/server/lib/MogileFS/Store.pm (revision 1198)
@@ -329,5 +329,5 @@
             return 1 if $self->was_duplicate_error;
             # This chunk is identical to condthrow, but we include it directly
-            # here as we know there is definetly an error, and we would like
+            # here as we know there is definitely an error, and we would like
             # the caller of this function.
             my ($pkg, $fn, $line) = caller;
@@ -596,5 +596,5 @@
     #   0 means immediate.  it's only on one host.
     #   1 means lower priority.  it's on 2+ but isn't happy where it's at.
-    #   unixtimestamp means at/after that time.  some previous error occurred.
+    #   unix timestamp means at/after that time.  some previous error occurred.
     # fromdevid, if not null, means which devid we should replicate from.  perhaps it's the only non-corrupt one.  otherwise, wherever.
     # failcount.  how many times we've failed, just for doing backoff of nexttry.
@@ -1003,5 +1003,5 @@
     };
     if ($@ || $dbh->err) {
-        # first is mysql's error code for duplicates
+        # first is MySQL's error code for duplicates
         if ($self->was_duplicate_error) {
             return 0;
@@ -1476,5 +1476,5 @@
 
     # FIXME: this blows. not random.  and good chances these will
-    # eventually get to point where they're un-rebalanacable, and we
+    # eventually get to point where they're un-rebalance-able, and we
     # never move on past the first 5000
     my @some_fids = List::Util::shuffle(@{
Index: trunk/server/lib/MogileFS/ProcManager.pm
===================================================================
--- trunk/server/lib/MogileFS/ProcManager.pm (revision 1120)
+++ trunk/server/lib/MogileFS/ProcManager.pm (revision 1198)
@@ -9,5 +9,5 @@
 
 # This class handles keeping lists of workers and clients and
-# assigning them to eachother when things happen.  You don't actually
+# assigning them to each other when things happen.  You don't actually
 # instantiate a procmanager.  the class itself holds all state.
 
@@ -532,5 +532,5 @@
     !replication
                 (Deprecated/old)
-                See the replication status for unreplicated files.
+                See the replication status for un-replicated files.
                 Output format:
                 <domain> <class> <devcount> <files>
@@ -578,5 +578,5 @@
     } elsif ($cmd =~ /^:repl_unreachable (\d+)/) {
         # announce to the other replicators that this fid can't be reached, but note
-        # that we don't actually drain the queue to the requestor, as the replicator
+        # that we don't actually drain the queue to the requester, as the replicator
         # isn't in a place where it can accept a queue drain right now.
         MogileFS::ProcManager->ImmediateSendToChildrenByJob('replicate', "repl_unreachable $1", $child);
Index: trunk/server/lib/MogileFS/Worker/Query.pm
===================================================================
--- trunk/server/lib/MogileFS/Worker/Query.pm (revision 1174)
+++ trunk/server/lib/MogileFS/Worker/Query.pm (revision 1198)
@@ -251,5 +251,5 @@
 
     # find suitable device(s) to put this file on.
-    my @dests; # MogileFS::Device objects which are suitabke
+    my @dests; # MogileFS::Device objects which are suitable
 
     while (scalar(@dests) < ($multi ? 3 : 1)) {
@@ -738,5 +738,5 @@
     my $host = MogileFS::Host->of_hostname($hostname);
 
-    # if we're createing a new host, require ip/port, and default to
+    # if we're creating a new host, require ip/port, and default to
     # host being down if client didn't specify
     if ($args->{update}) {
@@ -1162,5 +1162,5 @@
 }
 
-# FIXME: this whole thing is gross, duplicative, dependendent on $dbh, and doesn't scale.
+# FIXME: this whole thing is gross, duplicative, dependent on $dbh, and doesn't scale.
 # stats needs total overhaul to not suck.
 sub cmd_stats {
@@ -1267,5 +1267,5 @@
     }
 
-    # now fid statitics
+    # now fid statistics
     if ($args->{fids} || $args->{all}) {
         my $max = $dbh->selectrow_array('SELECT MAX(fid) FROM file');
@@ -1480,5 +1480,5 @@
     }
 
-    # add in any stats which might not've been summarized yet.,,
+    # add in any stats which might have not been summarized yet.,,
     my $max_logid = $sto->max_fsck_logid;
     my $min_logid = MogileFS::Util::max($intss->("fsck_start_maxlogid"),
@@ -1520,8 +1520,8 @@
         'bad_params' => "Invalid parameters to command; please see documentation",
         'class_exists' => "That class already exists in that domain",
-        'class_has_files' => "Class still has files, uanble to delete",
+        'class_has_files' => "Class still has files, unable to delete",
         'class_not_found' => "Class not found",
         'db' => "Database error",
-        'domain_has_files' => "Domain still has files, uanble to delete",
+        'domain_has_files' => "Domain still has files, unable to delete",
         'domain_exists' => "That domain already exists",
         'domain_not_empty' => "Domain still has classes, unable to delete",
Index: trunk/server/lib/MogileFS/Worker/Replicate.pm
===================================================================
--- trunk/server/lib/MogileFS/Worker/Replicate.pm (revision 1147)
+++ trunk/server/lib/MogileFS/Worker/Replicate.pm (revision 1198)
@@ -250,5 +250,5 @@
     return 0 unless $sto->isa("MogileFS::Store::MySQL");
 
-    # call this $mdbh to indiciate it's a MySQL dbh, and to help grepping
+    # call this $mdbh to indicate it's a MySQL dbh, and to help grepping
     # for old handles.  :)
     my $mdbh = $sto->dbh;
@@ -401,5 +401,5 @@
     # case where file is in file_on because not yet deleted, but
     # has been replaced/deleted in 'file' table...).  not too harmful
-    # (just nosiy) if thise line didn't exist, but whatever... it
+    # (just noisy) if this line didn't exist, but whatever... it
     # makes stuff cleaner on my intentionally-corrupted-for-fsck-testing
     # dev machine...
@@ -434,5 +434,5 @@
         # nothing to do, even with this devfid masked away.
         # so let's figure it out... if this devfid still exists,
-        # we're overreplicated, else we just lost the race.
+        # we're over-replicated, else we just lost the race.
         if ($devfid->exists) {
             # over-replicated
@@ -597,5 +597,5 @@
         last if $rr->is_happy;
 
-        my @ddevs;  # dest devs, in order of preferrence
+        my @ddevs;  # dest devs, in order of preference
         my $ddevid; # dest devid we've chosen to copy to
         if (@ddevs = $rr->copy_to_one_of_ideally) {
Index: trunk/server/lib/MogileFS/Worker/Delete.pm
===================================================================
--- trunk/server/lib/MogileFS/Worker/Delete.pm (revision 1037)
+++ trunk/server/lib/MogileFS/Worker/Delete.pm (revision 1198)
@@ -7,5 +7,5 @@
 
 # we select 1000 but only do a random 100 of them, to allow
-# for stateless paralleism
+# for stateless parallelism
 use constant LIMIT => 1000;
 use constant PER_BATCH => 100;
@@ -78,5 +78,5 @@
     # BUT NOTE:
     #    the fids might exist on one of the devices in devids column if we assigned them those,
-    #    they wrote some to one of them, then they died or for wahtever reason didn't create_close
+    #    they wrote some to one of them, then they died or for whatever reason didn't create_close
     #    to use, so we shouldn't delete from tempfile before going on a hunt of the missing fid.
     #    perhaps we should just add to the file_on table for both devids, and let the regular delete
Index: trunk/server/lib/MogileFS/Device.pm
===================================================================
--- trunk/server/lib/MogileFS/Device.pm (revision 1166)
+++ trunk/server/lib/MogileFS/Device.pm (revision 1198)
@@ -374,5 +374,5 @@
     if ($ans && $ans =~ m!HTTP/1\.[01] (400|405|501)!) {
         $self->{no_mkcol} = 1;
-        # TODO: move this into method on device, which propogates to parent
+        # TODO: move this into method on device, which propagates to parent
         # and also receive from parent.  so all query workers share this knowledge
         return 1;
Index: trunk/server/lib/MogileFS/FID.pm
===================================================================
--- trunk/server/lib/MogileFS/FID.pm (revision 1114)
+++ trunk/server/lib/MogileFS/FID.pm (revision 1198)
@@ -150,5 +150,5 @@
 # returns array of devids that this fid is on
 # NOTE: TODO: by default, this doesn't cache.  callers might be surprised from
-#   having an old version later on.  before caching is added, auditting needs
+#   having an old version later on.  before caching is added, auditing needs
 #   to be done.
 sub devids {
Index: trunk/server/CHANGES
===================================================================
--- trunk/server/CHANGES (revision 1183)
+++ trunk/server/CHANGES (revision 1198)
@@ -1,3 +1,5 @@
-        * Postgres locking routines did not include the hostname for the lock
+        * Many spelling errors corrected.
+
+        * PostGres locking routines did not include the hostname for the lock
           release.
 
@@ -12,5 +14,5 @@
         * Fix MultipleHosts replication policy to no longer return desperate
           devices after no longer being desperate, instead returning a state
-          which will queue for retries in the future till it can be truely
+          which will queue for retries in the future till it can be truly
           happy. This prevents files from being replicated to all writable
           devs when there are two few writable hosts to satisfy the policy.
@@ -78,10 +80,10 @@
         * Add a safety check to ensure that Postgresql-8.2 or newer is used.
 
-        * Update mogdbsetup usage, and ensure it choses the correct admin
+        * Update mogdbsetup usage, and ensure it chooses the correct admin
           username automatically.
 
         * Document the --type option to mogdbsetup.
 
-        * Introduce the Postgres Store implementation. The locking system might
+        * Introduce the PostGres Store implementation. The locking system might
           still have issues, beware of stale locks! Initial prototype by Radu
           Greab <rg@yx.ro>, and developed heavily by Robin H. Johnson
@@ -100,5 +102,5 @@
 
         * The unix_timestamp function belongs to the Store, not other classes.
-          Need to add testcases for process_deletes and stats.
+          Need to add test cases for process_deletes and stats.
 
         * Using NULL during an INSERT for the AUTO_INCREMENT column does not
@@ -106,5 +108,5 @@
           to the INSERT instead.
 
-        * Clean up all raw usages of UNIX_TIMETAMP() function, in preparation
+        * Clean up all raw usages of UNIX_TIMESTAMP() function, in preparation
           for database independence. If you need the unix timestamp, include the output
           of $self->unix_timestamp directly into your query.
@@ -139,5 +141,5 @@
           DeviceStates interface.
 
-        * use signifigantly less CPU when re-broadcasting around
+        * use significantly less CPU when re-broadcasting around
           iostat device utilization% to child processes.  (future:
           don't rebroadcast at all and use shared memory)
@@ -280,5 +282,5 @@
 
         * test cleanup/robustness improvements.  properly skips testing when
-          testin deps not found.  but searches harder for them now, too.
+          testing deps not found.  but searches harder for them now, too.
           tests run under "make disttest".
 
@@ -301,5 +303,5 @@
 
 2007-03-16:
-        * mogstored: make child processes be exec'ed (as as their own scripts, not inhertting
+        * mogstored: make child processes be exec'ed (as as their own scripts, not inheriting
           Perlbal, Linux::AIO/IO::AIO, etc baggage).  so they don't own listening
           sockets, pipes to child workers, signal handlers, etc.  just a lot
@@ -355,5 +357,5 @@
 
 2006-03-01 (Brad)
-        * mogilefsd: fix dataloss bug when the 'tempfile' table is Innodb and the
+        * mogilefsd: fix dataloss bug when the 'tempfile' table is InnoDB and the
            server is restarted while the tempfile table is empty.
 
Index: trunk/server/mogilefsd
===================================================================
--- trunk/server/mogilefsd (revision 1082)
+++ trunk/server/mogilefsd (revision 1198)
@@ -103,5 +103,5 @@
 =head1 SEE ALSO
 
-L<mogstored> -- MogilefS storage daemon
+L<mogstored> -- MogileFS storage daemon
 
 L<http://danga.com/mogilefs/>
Index: trunk/api/perl/MogileFS-Client/debian/control
===================================================================
--- trunk/api/perl/MogileFS-Client/debian/control (revision 166)
+++ trunk/api/perl/MogileFS-Client/debian/control (revision 1198)
@@ -10,4 +10,4 @@
 Depends: ${perl:Depends}, libio-stringy-perl, libwww-perl
 Description: perl client for MogileFS
- MogileFS.pm provides a the perl client for the MogileFS application-level 
+ MogileFS.pm provides a perl client for the MogileFS application-level
  distributed filesystem.
Index: trunk/api/perl/MogileFS-Client/lib/MogileFS/Backend.pm
===================================================================
--- trunk/api/perl/MogileFS-Client/lib/MogileFS/Backend.pm (revision 749)
+++ trunk/api/perl/MogileFS-Client/lib/MogileFS/Backend.pm (revision 1198)
@@ -13,5 +13,5 @@
 use fields ('hosts',        # arrayref of "$host:$port" of mogilefsd servers
             'host_dead',    # "$host:$port" -> $time  (of last connect failure)
-            'lasterr',      # string: \w+ identifer of last error
+            'lasterr',      # string: \w+ identifier of last error
             'lasterrstr',   # string: english of last error
             'sock_cache',   # cached socket to mogilefsd tracker
Index: trunk/api/perl/MogileFS-Client/lib/MogileFS/NewHTTPFile.pm
===================================================================
--- trunk/api/perl/MogileFS-Client/lib/MogileFS/NewHTTPFile.pm (revision 816)
+++ trunk/api/perl/MogileFS-Client/lib/MogileFS/NewHTTPFile.pm (revision 1198)
@@ -180,5 +180,5 @@
 
 # abstracted write function that uses non-blocking I/O and checking for
-# writability to ensure that we don't get stuck doing a write if the
+# writeability to ensure that we don't get stuck doing a write if the
 # node we're talking to goes down.  also handles logic to fall back to
 # a backup node if we're on our first write and the first node is down.
Index: trunk/api/perl/MogileFS-Client/lib/MogileFS/Client.pm
===================================================================
--- trunk/api/perl/MogileFS-Client/lib/MogileFS/Client.pm (revision 1149)
+++ trunk/api/perl/MogileFS-Client/lib/MogileFS/Client.pm (revision 1198)
@@ -156,5 +156,5 @@
 =head2 errstr
 
-Returns string representation of the last error that occured.  It
+Returns string representation of the last error that occurred.  It
 includes the error code (same as method 'errcode') and a space before
 the optional English error message.
Index: trunk/api/perl/MogileFS-Client-FilePaths/lib/MogileFS/Client/FilePaths.pm
===================================================================
--- trunk/api/perl/MogileFS-Client-FilePaths/lib/MogileFS/Client/FilePaths.pm (revision 1139)
+++ trunk/api/perl/MogileFS-Client-FilePaths/lib/MogileFS/Client/FilePaths.pm (revision 1198)
@@ -40,5 +40,5 @@
 provided in the FilePaths plugin.
 
-All methods are inhereted and usable from the MogileFS::Client library, with only the exceptions listed below.
+All methods are inherited and usable from the MogileFS::Client library, with only the exceptions listed below.
 
 =cut

Index: trunk/server/lib/MogileFS/ReplicationPolicy/Union.pm
===================================================================
--- trunk/server/lib/MogileFS/ReplicationPolicy/Union.pm (revision 1110)
+++ trunk/server/lib/MogileFS/ReplicationPolicy/Union.pm (revision 1198)
@@ -39,9 +39,9 @@
 =head1 NAME
 
-MogileFS::ReplicationPolicy::Union -- satisify 2 or more replication policies
+MogileFS::ReplicationPolicy::Union -- satisfy 2 or more replication policies
 
 =head1 RULES
 
-Use this replication policy to satisify multiple replication policies.
+Use this replication policy to satisfy multiple replication policies.
 For instance:
 